import { ListRow } from '../../e2elib/lib/src/pageobjects/list/listrow.component';
import { ListBase } from '../../libappbase/listbase';
import { ButtonSOP } from '../../libappsop/buttonsop';
import { FormSOP } from '../../libappsop/formsop';

export class FormSanityCheck extends FormSOP {
  // Buttons
  public btnRefresh = new ButtonSOP('ButtonRefresh');

  // Lists
  public listSanityCheckGroup = new ListSanityCheckGroup();
  public listSanityCheckMessage = new ListSanityCheckMessage();

  public constructor() {
    super('FormSanityCheck');
  }
}

export class ListSanityCheckGroup extends ListBase {
  public constructor() {
    super('ListSanityCheckGroup');
  }

  /**
   * Get SanityCheckGroup row by pass-in SanityCheckGroup name and parent SanityCheckGroup name
   *
   * @param name target SanityCheckGroup name
   * @param parentName parent row SanityCheckGroup name of target SanityCheckGroup
   * @returns row of SanityCheckGroup
   */
  public async getSanityCheckGroupByName(name: string, parentNames?: string[]): Promise<ListRow> {
    return this.getRowByCellValue(ListSanityCheckGroupColumn.Name, name, parentNames);
  }
}

export class ListSanityCheckMessage extends ListBase {
  public constructor() {
    super('ListSanityCheckMessage');
  }

  /**
   * Return Sanity row that matches the Description given
   *
   * @param displayName target entity Description
   * @param parentNames target entity parent(s) Description
   *
   * @return ListRow that matches the provided Description
   */
  public async getRowByName(description: string, parentNames?: string[]): Promise<ListRow> {
    const listRow = await this.getRowByCellValue(ListSanityCheckMessageColumn.Description, description, parentNames);
    return listRow;
  }
}

// List SanityCheckMessage columns
export enum ListSanityCheckMessageColumn {
  Description = 'Description',
}
// List SanityCheckGroup columns
export enum ListSanityCheckGroupColumn {
  Name = 'Name',
}
